@@ -37,11 +37,13 @@ class Command {
     UString m_tag1 ;
     int m_tag2;
     IDebugger::VariableSafePtr m_var ;
+    sigc::slot_base m_slot;
 
 public:
 
-    Command ():
-      m_tag2 (0)
+    Command ()  :
+        m_tag2 (0),
+        m_slot (0)
     {
         clear ();
     }
@@ -49,14 +51,16 @@ public:
     /// \param a_value a textual command to send to the debugger.
     Command (const UString &a_value) :
         m_value (a_value),
-        m_tag2 (0)
+        m_tag2 (0),
+        m_slot (0)
     {
     }
 
     Command (const UString &a_name, const UString &a_value) :
         m_name (a_name),
         m_value (a_value),
-        m_tag2 (0)
+        m_tag2 (0),
+        m_slot (0)
     {
     }
 
@@ -66,7 +70,8 @@ public:
         m_cookie (a_cookie),
         m_name (a_name),
         m_value (a_value),
-        m_tag2 (0)
+        m_tag2 (0),
+        m_slot (0)
     {
     }
 
@@ -95,6 +100,23 @@ public:
     void variable (const IDebugger::VariableSafePtr a_in) {m_var = a_in;}
     IDebugger::VariableSafePtr variable () const {return m_var;}
 
+    bool has_slot () const
+    {
+        return m_slot;
+    }
+
+    template<class T>
+    void set_slot (T &a_slot)
+    {
+        m_slot = a_slot;
+    }
+
+    template<class T>
+    const T& get_slot () const
+    {
+        return reinterpret_cast<const T&> (m_slot);
+    }
+
     /// @}
 
     void clear ()
@@ -372,10 +394,68 @@ public:
         size_t m_memory_address;
         bool m_has_memory_values;
 
+        // Variable Object
+        IDebugger::VariableSafePtr m_variable;
+        bool m_has_variable;
+
+        // Variable Object deletion information
+        int m_nb_variable_deleted;
+
+        // Children variables of a given variable.
+        vector<IDebugger::VariableSafePtr> m_variable_children;
+        bool m_has_variable_children;
+
+        // Updated sub variables (direct/indirect children)
+        // of a given variable
+        list<IDebugger::VariableSafePtr> m_changed_var_list;
+        bool m_has_changed_var_list;
+
+        // The path expression of a variable object.
+        UString m_path_expression;
+        bool m_has_path_expression;
 
     public:
         ResultRecord () {clear () ;}
 
+        /// blank out everything
+        void clear ()
+        {
+            m_kind = UNDEFINED ;
+            m_breakpoints.clear () ;
+            m_attrs.clear () ;
+            m_call_stack.clear () ;
+            m_has_call_stack = false ;
+            m_frames_parameters.clear () ;
+            m_has_frames_parameters = false ;
+            m_local_variables.clear () ;
+            m_has_local_variables = false ;
+            m_variable_value.reset () ;
+            m_has_variable_value = false ;
+            m_thread_list.clear () ;
+            m_has_thread_list = false ;
+            m_thread_id = 0;
+            m_frame_in_thread.clear () ;
+            m_thread_id_got_selected = false;
+            m_file_list.clear () ;
+            m_has_file_list = false ;
+            m_has_current_frame_in_core_stack_trace = false ;
+            m_has_changed_registers = false;
+            m_changed_registers.clear ();
+            m_has_register_values = false;
+            m_register_values.clear ();
+            m_has_register_names = false;
+            m_register_names.clear ();
+            m_memory_values.clear ();
+            m_memory_address = 0;
+            m_has_memory_values = false;
+            m_has_variable = false;
+            m_nb_variable_deleted = 0;
+            m_has_variable_children = false;
+            m_has_changed_var_list = false;
+            m_path_expression.clear ();
+            m_has_path_expression = false;
+        }
+
         /// \name accessors
 
         /// @{
@@ -403,15 +483,23 @@ public:
         }
         bool has_register_names () const { return m_has_register_names; }
         void has_register_names (bool a_flag) { m_has_register_names = a_flag; }
-        const std::map<IDebugger::register_id_t, UString>& register_names () const { return m_register_names; }
-        void register_names (const std::map<IDebugger::register_id_t, UString>& a_names)
+        const std::map<IDebugger::register_id_t, UString>& register_names () const
+        {
+            return m_register_names;
+        }
+
+        void register_names
+            (const std::map<IDebugger::register_id_t, UString>& a_names)
         {
             m_register_names = a_names;
             has_register_names (true);
         }
 
         bool has_changed_registers () const { return m_has_changed_registers; }
-        void has_changed_registers (bool a_flag) { m_has_changed_registers = a_flag; }
+        void has_changed_registers (bool a_flag)
+        {
+            m_has_changed_registers = a_flag;
+        }
         const std::list<IDebugger::register_id_t>& changed_registers () const
         {
             return m_changed_registers;
@@ -428,7 +516,8 @@ public:
         {
             return m_register_values;
         }
-        void register_values (const std::map<IDebugger::register_id_t, UString>& a_regs)
+        void register_values
+            (const std::map<IDebugger::register_id_t, UString>& a_regs)
         {
             m_register_values = a_regs;
             has_register_values (true);
@@ -436,7 +525,10 @@ public:
 
         bool has_memory_values () const { return m_has_memory_values; }
         void has_memory_values (bool a_flag) { m_has_memory_values = a_flag; }
-        const std::vector<uint8_t>& memory_values () const { return m_memory_values; }
+        const std::vector<uint8_t>& memory_values () const
+        {
+            return m_memory_values;
+        }
         size_t memory_address () const { return m_memory_address; }
         void memory_values (size_t a_address, const std::vector<uint8_t>& a_values)
         {
@@ -541,39 +633,90 @@ public:
             m_has_current_frame_in_core_stack_trace = a_in ;
         }
 
+        bool has_variable () {return m_has_variable; }
+        void has_variable (bool a_in) {m_has_variable = a_in;}
+
+        IDebugger::VariableSafePtr variable () const
+        {
+            return m_variable;
+        }
+        void variable (const IDebugger::VariableSafePtr a_var)
+        {
+            m_variable = a_var;
+            has_variable (true);
+        }
+
+        int number_of_variables_deleted () const
+        {
+            return m_nb_variable_deleted;
+        }
+
+        void number_of_variables_deleted (int a_nb)
+        {
+            m_nb_variable_deleted = a_nb;
+        }
+
+        bool has_variable_children () const
+        {
+            return m_has_variable_children;
+        }
+        void has_variable_children (bool a_in)
+        {
+            m_has_variable_children = a_in;
+        }
+
+        const vector<IDebugger::VariableSafePtr>&
+        variable_children () const
+        {
+            return m_variable_children;
+        }
+        void
+        variable_children (const vector<IDebugger::VariableSafePtr> &a_vars)
+        {
+            m_variable_children = a_vars;
+            has_variable_children (true);
+        }
+
+        bool has_changed_var_list () const
+        {
+            return m_has_changed_var_list;
+        }
+        void has_changed_var_list (bool a_in)
+        {
+            m_has_changed_var_list = a_in;
+        }
+        const list<IDebugger::VariableSafePtr>& changed_var_list () const
+        {
+            return m_changed_var_list;
+        }
+        void changed_var_list (const list<IDebugger::VariableSafePtr> &a_in)
+        {
+            m_changed_var_list = a_in;
+            has_changed_var_list (true);
+        }
+
+        const UString& path_expression () const
+        {
+            return m_path_expression;
+        }
+        void path_expression (const UString &a_str)
+        {
+            m_path_expression = a_str;
+            if (!a_str.empty ())
+                has_path_expression (true);
+        }
+
+        bool has_path_expression () const
+        {
+            return m_has_path_expression;
+        }
+        void has_path_expression (bool a)
+        {
+            m_has_path_expression = a;
+        }
+
         /// @}
 
-        void clear ()
-        {
-            m_kind = UNDEFINED ;
-            m_breakpoints.clear () ;
-            m_attrs.clear () ;
-            m_call_stack.clear () ;
-            m_has_call_stack = false ;
-            m_frames_parameters.clear () ;
-            m_has_frames_parameters = false ;
-            m_local_variables.clear () ;
-            m_has_local_variables = false ;
-            m_variable_value.reset () ;
-            m_has_variable_value = false ;
-            m_thread_list.clear () ;
-            m_has_thread_list = false ;
-            m_thread_id = 0;
-            m_frame_in_thread.clear () ;
-            m_thread_id_got_selected = false;
-            m_file_list.clear () ;
-            m_has_file_list = false ;
-            m_has_current_frame_in_core_stack_trace = false ;
-            m_has_changed_registers = false;
-            m_changed_registers.clear ();
-            m_has_register_values = false;
-            m_register_values.clear ();
-            m_has_register_names = false;
-            m_register_names.clear ();
-            m_memory_values.clear ();
-            m_memory_address = 0;
-            m_has_memory_values = false;
-        }
     };//end class ResultRecord
 
 private:
